// **************************************************************************
// *                                                                        *
// *   Analog Talking Glow In The Dark 3D printed Clock                     *
// *   by John Guarnero                                 	            *
// *   http://guarnero.com                                   	            *
// *   10/11/2015                                                           *
// **************************************************************************

//Clock Includes and Defines
#include "Wire.h"
#include <RTClib.h>
#define DS1307_ADDRESS 0x68 //default address of the 1307 RTC module

//Music Maker Includes and Defines
#include <SPI.h>
#include <Adafruit_VS1053.h>
#include <SD.h>
#define SHIELD_RESET  -1       // VS1053 reset pin (unused!)
#define SHIELD_CS     7        // VS1053 chip select pin (output)
#define SHIELD_DCS    6        // VS1053 Data/command select pin (output)
#define CARDCS 4               // Card chip select pin
#define DREQ 3                 // VS1053 Data request, ideally an Interrupt pin

Adafruit_VS1053_FilePlayer musicPlayer = 
Adafruit_VS1053_FilePlayer(SHIELD_RESET, SHIELD_CS, SHIELD_DCS, DREQ, CARDCS);


byte one = 0x01; //variable used to point to time setting for minutes in DS1307
byte two = 0x02; //variable used to point to time setting for minutes in DS1307
byte hourval, minuteval, secondval; // holds the actual time
byte hourval_set;   // holds the hour set time
byte minuteval_set; // holds the minute set time

int Meter_AM_PM_Pin = 5;
int Meter_Hours_Pin = 8;
int Meter_Minutes_Pin = 9;
int Meter_Seconds_Pin = 10;
int AM_PM;
int hourval12;
int Powerup = 1; //system just powered up
int LED_Brightness = 200;


RTC_DS1307 RTC; // Establish clock object
DateTime Clock; // Holds current clock time


void setup() {
//Music maker uses pins 3,4,6,7,11,12,13
//Arduino Mega SDA and SCL pins are 20 & 21 if Arduino uno, SDA & SCL pins are A4 & A5
  // Initialize The Music Player
  if (! musicPlayer.begin())
  { // Initialize The Music Player
     Serial.println(F("VS1053 Not Found"));
     while (1);
  }
  if (!SD.begin(CARDCS))
  {
  }

   // Set volume for left, right channels. lower numbers == louder volume!
    musicPlayer.setVolume(20,20);
  
  if (! musicPlayer.useInterrupt(VS1053_FILEPLAYER_PIN_INT))
    Serial.println(F("DREQ pin is not an interrupt pin"));

  pinMode(2, OUTPUT);       // declare pin 2 to be an output (LEDS)

  pinMode(5, OUTPUT);       // declare pin 5 to be an output (Meter AM/PM)
  pinMode(8, OUTPUT);       // declare pin 8 to be an output (Meter Hour)
  pinMode(9, OUTPUT);       // declare pin 9 to be an output (Meter Minutes)
  pinMode(10, OUTPUT);       // declare pin 10 to be an output (Meter Seconds)
  
  pinMode(22, INPUT); // declare pin 22 to be an input with internal pullups (Hour Set Time Rocker Switch - Red wire) // On = 1
  pinMode(24, INPUT); // declare pin 24 to be an input with internal pullups (Minute Set Time Rocker Switch - Yellow wire) // On = 1
  pinMode(26, INPUT); // declare pin 26 to be an input with internal pullups (Talk On/Off Rocker Switch - Green wire) // On = 1
  pinMode(28, INPUT); // declare pin 28 to be an input with internal pullups (LED On/Off Rocker Switch - Blue wire) // On = 1
  pinMode(30, INPUT_PULLUP); // declare pin 30 to be an input with internal pullups (Decrement Switch - Black Wire) // On = 0
  pinMode(32, INPUT_PULLUP); // declare pin 30 to be an input with internal pullups (Increment Switch - White Wire) // On = 0
  
  Wire.begin();
  RTC.begin();              // begin clock
  Serial.begin(9600);       // define serial for debug of program

//  RTC.adjust(DateTime(__DATE__, __TIME__));  // Run this to set the time to the PC Time on Arduino power up - enable for debug and troubleshooting only
  }


void loop() {

    // Start playing a file, then we can do stuff while waiting for it to finish
 if (musicPlayer.stopped())
 {
 delay(1);
 }
   
  int rocker_hour = digitalRead(22); // On = 1
  int rocker_minute = digitalRead(24); // On = 1
  int rocker_talk = digitalRead(26); // On = 1
  int rocker_led = digitalRead(28); // On = 1
  int switch_dec = digitalRead(30); // On = 0
  int switch_inc = digitalRead(32); // On = 0
  int hourvoltage;  
  int minutevoltage;
  int secondvoltage;
   
  // Get the current time from the real time clock module
  Clock = RTC.now();           // get the RTC time

  secondval = Clock.second();  // get seconds
  minuteval = Clock.minute();  // get minutes
  hourval = Clock.hour();      // get hours

 // This is here for serial debug as needed
 // Serial.print("rocker_hour: "); Serial.print(rocker_hour); Serial.print('\n');
 // Serial.print("rocker_minute: "); Serial.print(rocker_minute); Serial.print('\n');
 // Serial.print("rocker_talk: "); Serial.print(rocker_talk); Serial.print('\n');
 // Serial.print("rocker_led: "); Serial.print(rocker_led); Serial.print('\n');
 // Serial.print("switch_dec: "); Serial.print(switch_dec); Serial.print('\n');
 // Serial.print("switch_inc: "); Serial.print(switch_inc); Serial.print('\n');
 // Serial.print("switch_inc: "); Serial.print(hourval); Serial.print('\n');

 
//LED Switch


//Turn the LEDs on
 if (rocker_led == 1) 
 {
    analogWrite(2, LED_Brightness);  //LED_Brightness level variable set at top of program 1-255 (255 is the brightest) 
    
 }

//Turn the LEDs off
 if (rocker_led == 0) 
 {
    digitalWrite(2, LOW); 
 }



//Analog Meter Time Display

//Dispay Hours On Analog Meter 
 
hourval12 = hourval;
if (hourval > 12)
{
 hourval12 = hourval - 12;       
}

if (hourval == 0) 
{
 hourval12 = 12;       
}

hourvoltage = map(hourval12, 0, 12, 0, 240); // Convert minutes to PWM duty cycle (0-255 is range so modify low and high last two numbers based on actual needle travel)
hourvoltage = hourvoltage + 0; //Meter Offset to adjust dial (+ moves needle to right and - moves needle to the left)
analogWrite(Meter_Hours_Pin, hourvoltage);

//Dispay Minutes On Analog Meter  
minutevoltage = map(minuteval, 0, 60, 12, 255); // Convert minutes to PWM duty cycle (0-255 is range so modify low and high last two numbers based on actual needle travel)
minutevoltage = minutevoltage + 0; //Meter Offset to adjust dial (+ moves needle to right and - moves needle to the left)
analogWrite(Meter_Minutes_Pin, minutevoltage);
 
//Dispay Seconds On Analog Meter  
secondvoltage = map(secondval, 0, 60, 15, 255); // Convert minutes to PWM duty cycle (0-255 is range so modify low and high last two numbers based on actual needle travel)
secondvoltage = secondvoltage + 0; //Meter Offset to adjust dial (+ moves needle to right and - moves needle to the left)
analogWrite(Meter_Seconds_Pin, secondvoltage);

//Dispay AM / PM On Analog Meter  
  if (hourval < 12)             // if hourval < 12 then its AM
 {
  analogWrite(Meter_AM_PM_Pin, 64); // AM
  AM_PM = 0; //AM is 0
 }
  else
 {
 analogWrite(Meter_AM_PM_Pin, 191); // PM
 AM_PM = 1; //PM is 1
 }


// Say Something On Power Up

if (Powerup  == 1) //System just powered up = 1 
 {
  (musicPlayer.startPlayingFile("POWERUP.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK ON POWERUP  
  delay (6000);
  Powerup = 0;
  }


// Speak the Time

if (hourval == 0 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //12:00 AM 
 {
  (musicPlayer.startPlayingFile("T12_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 0 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //12:30 AM 
 {
  (musicPlayer.startPlayingFile("T12_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 1 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //01:00 AM 
 {
  (musicPlayer.startPlayingFile("T01_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 1 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //01:30 AM 
 {
  (musicPlayer.startPlayingFile("T01_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 2 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //02:00 AM 
 {
  (musicPlayer.startPlayingFile("T02_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 2 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //02:30 AM 
 {
  (musicPlayer.startPlayingFile("T02_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 3 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //03:00 AM 
 {
  (musicPlayer.startPlayingFile("T03_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 3 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //03:30 AM 
 {
  (musicPlayer.startPlayingFile("T03_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 4 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //04:00 AM 
 {
  (musicPlayer.startPlayingFile("T04_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 4 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //04:30 AM 
 {
  (musicPlayer.startPlayingFile("T04_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 5 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //05:00 AM 
 {
  (musicPlayer.startPlayingFile("T05_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 5 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //05:30 AM 
 {
  (musicPlayer.startPlayingFile("T05_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 6 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //06:00 AM 
 {
  (musicPlayer.startPlayingFile("T06_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 6 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //06:30 AM 
 {
  (musicPlayer.startPlayingFile("T06_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 7 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //07:00 AM 
 {
  (musicPlayer.startPlayingFile("T07_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 7 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //07:30 AM 
 {
  (musicPlayer.startPlayingFile("T07_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 8 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //08:00 AM 
 {
  (musicPlayer.startPlayingFile("T08_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 8 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //08:30 AM 
 {
  (musicPlayer.startPlayingFile("T08_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 9 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //09:00 AM 
 {
  (musicPlayer.startPlayingFile("T09_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 9 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //09:30 AM 
 {
  (musicPlayer.startPlayingFile("T09_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 10 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //10:00 AM 
 {
  (musicPlayer.startPlayingFile("T10_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME   
  delay (6000);
  }

if (hourval == 10 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //10:30 AM 
 {
  (musicPlayer.startPlayingFile("T10_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 11 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //11:00 AM 
 {
   (musicPlayer.startPlayingFile("T11_00A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 11 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //11:30 AM 
 {
   (musicPlayer.startPlayingFile("T11_30A.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 12 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //12:00 PM 
 {
  (musicPlayer.startPlayingFile("T12_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 12 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //12:30 PM 
 {
  (musicPlayer.startPlayingFile("T12_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 13 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //1:00 PM 
 {
  (musicPlayer.startPlayingFile("T01_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 13 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //1:30 PM 
 {
  (musicPlayer.startPlayingFile("T01_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 14 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //2:00 PM 
 {
  (musicPlayer.startPlayingFile("T02_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 14 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //2:30 PM 
 {
  (musicPlayer.startPlayingFile("T02_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 15 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //3:00 PM 
 {
  (musicPlayer.startPlayingFile("T03_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 15 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //3:30 PM 
 {
  (musicPlayer.startPlayingFile("T03_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 16 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //4:00 PM 
 {
  (musicPlayer.startPlayingFile("T04_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 16 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //4:30 PM 
 {
  (musicPlayer.startPlayingFile("T04_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }
  
if (hourval == 17 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //5:00 PM 
 {
  (musicPlayer.startPlayingFile("T05_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 17 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //5:30 PM 
 {
  (musicPlayer.startPlayingFile("T05_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }
   
if (hourval == 18 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //6:00 PM 
 {
  (musicPlayer.startPlayingFile("T06_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 18 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //6:30 PM 
 {
  (musicPlayer.startPlayingFile("T06_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  } 
  
if (hourval == 19 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //7:00 PM 
 {
  (musicPlayer.startPlayingFile("T07_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 19 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //7:30 PM 
 {
  (musicPlayer.startPlayingFile("T07_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }   
  
if (hourval == 20 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //8:00 PM 
 {
  (musicPlayer.startPlayingFile("T08_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 20 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //8:30 PM 
 {
  (musicPlayer.startPlayingFile("T08_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }   
  
if (hourval == 21 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //9:00 PM 
 {
  (musicPlayer.startPlayingFile("T09_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 21 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //9:30 PM 
 {
  (musicPlayer.startPlayingFile("T09_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }   
   
if (hourval == 22 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //10:00 PM 
 {
  (musicPlayer.startPlayingFile("T10_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 22 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //10:30 PM 
 {
  (musicPlayer.startPlayingFile("T10_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }   
    
if (hourval == 23 && minuteval == 0 && secondval <= 1 && rocker_talk == HIGH) //11:00 PM 
 {
  (musicPlayer.startPlayingFile("T11_00P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }

if (hourval == 23 && minuteval == 30 && secondval <= 1 && rocker_talk == HIGH) //11:30 PM 
 {
  (musicPlayer.startPlayingFile("T11_30P.mp3")); //PLACE '//' IN FRONT OF THIS YOU DONT WANT IT TO SPEAK AT THIS TIME  
  delay (6000);
  }   



//check to see if hour set rocker is on and increment is pressed
  if (rocker_hour == HIGH && switch_inc == LOW)
  
  {
  if (hourval_set < 24)
  {
    hourval_set = hourval_set + 1;
    delay (100);
  }

  if (hourval_set >= 24)
  {
    hourval_set = 0;
  }

//  setDateTime_hours();
    Wire.beginTransmission(DS1307_ADDRESS);
    Wire.write(two); //write 2 for hours
    Wire.write(decToBcd(hourval_set));
    Wire.endTransmission();
    delay(300);
  }



//check to see if the hour set rocker is on and decrement is pressed
  if (rocker_hour == HIGH && switch_dec == LOW)
  {
  if (hourval_set > 0)
  {
    hourval_set = hourval_set - 1;
    delay (100);
  }

  if (hourval_set <= 0)
  {
    hourval_set = 24;
  }

//  setDateTime_hours();
    Wire.beginTransmission(DS1307_ADDRESS);
    Wire.write(two); //write 2 for hours
    Wire.write(decToBcd(hourval_set));
    Wire.endTransmission();
    delay(300);
  }
  

 
//check to see if the minute set rocker is one and increment is pressed
  if (rocker_minute == HIGH && switch_inc == LOW)
  {
   if (minuteval_set < 60)
  {
    minuteval_set = minuteval_set + 1;
    delay (50);
  }

  if (minuteval_set >= 60)
  {
    minuteval_set = 0;
  }
//  setDateTime_minutes();
    Wire.beginTransmission(DS1307_ADDRESS);
    Wire.write(one); //write 1 for minutes
    Wire.write(decToBcd(minuteval_set));
    Wire.endTransmission();
    delay(150);
  }

//check to see if the minute set rocker is one and decrement is pressed
  if (rocker_minute == HIGH && switch_dec == LOW)
  {
    if (minuteval_set > 0)
  {
    minuteval_set = minuteval_set - 1;
    delay (50);
  }

  if (minuteval_set <= 0)
  {
    minuteval_set = 59;
  }
//  setDateTime_minutes();
    Wire.beginTransmission(DS1307_ADDRESS);
    Wire.write(one); //write 1 for minutes
    Wire.write(decToBcd(minuteval_set));
    Wire.endTransmission();
    delay(150);
  }

} // end of loop
 


byte decToBcd(byte val) { // Convert normal decimal numbers to binary coded decimal - used for DS1307
   return ( (val / 10 * 16) + (val % 10) );
}

byte bcdToDec(byte val)  { // Convert binary coded decimal to normal decimal numbers - used for DS1307
   return ( (val / 16 * 10) + (val % 16) );
}
